import os
import yaml
import shutil


def _here():
    """standard "here" helper function"""
    return os.path.dirname(os.path.realpath(__file__))


def _cwd():
    return os.getcwd()


class DjangoInstall:

    # meta refers to the configuration file for this script
    meta = "_files/conf.yaml"

    # the basic conf is basic for the installation we are
    # setting up.
    basicconfig = None
    destinationfolder = None

    def __init__(self, basicconfigfile=None, destinationfolder=""):

        if basicconfigfile is None:
            meta = self._getmetainfo()
            self.basicconfig = os.path.join(_here(),
                                            meta['filepaths']['basic']['src'])
        else:
            self.basicconfig = os.path.join(_cwd(), basicconfigfile)

        self.destinationfolder = destinationfolder

    def _getbranches(self):
        """ util function to quickly get back the branches we will be using"""
        if not self.basicconfig:
            conf = self._getmetainfo()
            self.basicconfig = os.path.join(_here(), conf['basic']['src'])

        stream = open(self.basicconfig)
        return yaml.load(stream)['branch']

    def _getmetainfo(self):
        """ function that returns a dict with all the config info
        """
        stream = open(os.path.join(_here(), self.meta))
        return yaml.load(stream)

    def install(self):
        conf = self._getmetainfo()

        # copy the main tree
        shutil.copytree(
            os.path.join(_here(), conf['directorystructure']['src']),
            os.path.join(_cwd(), self.destinationfolder))

        dstbasic = os.path.join(_cwd(), self.destinationfolder,
                                conf['filepaths']['basic']['dst'])

        shutil.copyfile(self.basicconfig, dstbasic)

        branches = self._getbranches()
        for b in branches:
            src = os.path.join(_here(), conf['filepaths']['virtualenv']['src'])

            filename = src.split(os.path.sep)[-1].replace('BRANCH', b)

            dst = os.path.join(_cwd(), self.destinationfolder,
                               conf['filepaths']['virtualenv']['dst'],
                               filename)

            shutil.copyfile(src, dst)



import os
import sys
import re
import logging
import subprocess
import string
from random import choice
from logging.handlers import RotatingFileHandler


def execcommand(commanddict, commandkey, commandname):
    """executes a command line process and returns info

        commanddict - dictionary containing tuples (commandname,
            parameterstring)

            (commandname should give the full path)

        e.g.
            commandkeydict['start'] = ('ls', '-x')
            commandkeydict['stop'] = ('ls', '-hla')

        commandkey, commandkeykey
    """

    info = dict()
    info['retval'] = subprocess.check_call(commanddict[commandkey])
    if info['retval'] == 0:
        info['message'] = "successfully executed {0} on {1}".format(
            commandkey, commandname)
    else:
        info['message'] = "error executing {0} on {1}".format(
            commandkey, commandname)

    return info


def makepassword(length=8):
    chars = string.letters + string.digits
    return ''.join([choice(chars) for i in range(length)])


def makesecretkey(length=50):
    return "".join([choice(
        "abcdefghijklmnopqrstuvwxyz0123456789!@#$%^&*(-_=+)")
        for i in range(50)])


def filterPick(_list, filter):
    # TODO:
    #   move this to a different file

    """
    Searches through a list for a regex term.  Use this instead of list.index
    when the search term is contained WITHIN the list items, for example,
    you are looking for the word "BRANCH" and the item that contains it
    has the word "BRANCH.sh".

    list.index won't return that!

    It returns the full text contained within the list item, so you can
    do a search on that (full text? NOTE: this is why comments are important!)

    original location:
        http://stackoverflow.com/questions/2436607/
        how-to-use-re-match-objects-in-a-list-comprehension

    filter - needs to be a regex.  For example:
        filter = re.compile('(searchterm)').search
    list - the list to search through
    """

    return [item for item in _list for match in (filter(item),) if match]


def regxListFind(_list, find):
    # TODO:
    #   move this to a different file

    regFilter = re.compile('({0})'.format(find)).search
    slist = filterPick(_list, regFilter)

    searchterm = slist[0]

    return searchterm


def create_logformatter(logformat=None, dateformat=None):
    """Helper class to create a standard logging formatter"""

    _lgfrmt = "%(asctime)s - %(levelname)-8s [%(filename)s::%(funcName)s "\
        "%(lineno)d] :: %(message)s\n"
    _dtfrmt = "%Y-%d-%m %H:%M"

    # Note: I get weird errors when I try to make _lgfrmt, and _dtfrmt into
    # default values for logformat and dateformat
    if logformat is None:
        logformat = _lgfrmt

    if dateformat is None:
        dateformat = _dtfrmt

    return logging.Formatter(logformat, dateformat)


def setup_logging(logdir=None, scrnlog=True,
                  txtlog=True, logger_name='standard',
                  logname='Standard.log', loglevel=logging.DEBUG,
                  screen_formatter=None, log_formatter=None, debug=True):
    """
    I forgot where I got this from.  But it's a convenient helper to
    set up logging across files.

    To use, do something like this in the initial file:

        utils_config.setup_logging('/tmp/logs', scrnlog=True,
            logname=_configuration['log.debug'])

        _logger1 = logging.getLogger('standard.core')


    Then when you want to use it somewhere else:
        _logger2 = logging.getLogger('standard.core')

    Both loggers will log to the same place as was set up.  You can also
    change the "loggername" to say 'frank', then the same retrieval
    commands would be:

        _anothernamefor_logger1 = logging.getLogger('frank.core')
        somerandom_logger2 = logging.getLogger('frank.core')
    """

    if debug is True:
        loglevel = logging.DEBUG
    else:
        loglevel = logging.INFO

    logdir = os.path.abspath(logdir)

    if not os.path.exists(logdir):
        os.mkdir(logdir)

    if log_formatter is None:
        log_formatter = create_logformatter()

    log = logging.getLogger(logger_name)
    log.setLevel(loglevel)

    if txtlog:
        txt_handler = RotatingFileHandler(
            os.path.join(logdir, logname), backupCount=5)

        txt_handler.doRollover()
        txt_handler.setFormatter(log_formatter)
        log.addHandler(txt_handler)
        log.info("Logger initialised.")

    if scrnlog:
        if screen_formatter is None:
            screen_formatter = log_formatter

        console_handler = logging.StreamHandler()
        console_handler.setFormatter(screen_formatter)
        log.addHandler(console_handler)


def duplicateList(_list):
    _list2 = list()
    for key in _list:
        _list2.append(list[key])
    return _list2


def confirmation(msg):
    """ Asks the user to input if he wishes to confirm whatever the
    message asks of the user.  Will repeat until it gets a good answer.
    """

    condition = True
    while condition:
        var = raw_input(msg)
        if var == "":
            var = 'Y'

        condition = var.upper() != 'Y' and var.upper() != 'N'
        if condition:
            print "You must enter either 'Y' or 'N'.\n"

        else:
            if var.upper() == 'Y':
                return True
            else:
                return False


def inspect_param(argv, argument, flag=False):
    """retrieve the argument we are looking for.  If flag is set to
        True then just check to see if the argument is there, and don't
        worry if there is an attendent value
    """

    if not flag:
        count = argv.count(argument)
        if count > 0:
            index = argv.index(argument)

            if index + 1 <= len(argv) - 1:
                return argv[index + 1]

        # no success
        return None

    else:
        count = argv.count(argument)
        if count > 0:
            return True
        else:
            return False


def inspect_parameters(argv, s_arg, l_arg, flag=False):
    """retrieve the argument we are looking for.  If flag is set to
        True then just check to see if the argument is there, and don't
        worry if there is an attendent value
    """

    val = inspect_param(argv, s_arg, flag)

    if val is None or val is False:
        val = inspect_param(argv, l_arg, flag)

    return val


def exit_err(err_msg, err_code=1, logger=None):
    """ Helper function to write messages to both the log and the
    console, also gives the error code.
    """
    message = err_msg + "\nExit code {0}\n".format(err_code)

    if logger is None:
        logging.debug(message)
    else:
        logger.debug(message)

    sys.stderr.write("\n" + message + "\n")
    sys.exit(err_code)


def extract_tuplelist(tuplist, key):
    """ This helper function is used with elpotrero.lib.utils.config.tree

        tuplelist - list of tuple values with the structure of (key,value)
        key - the value types you are looking for

        return a list consisting only of the values referenced by key
    """
    somelist = list()

    for item in tuplist:
        if item[0] == key:
            somelist.append(item[1])

    return somelist


def tree(node, parents=None):
    """ Walks through a dictionary/list tree where the format is:
    {'top':{'level1':['item1', 'item2'],
    'level2':{'sublevel1':['item1','item2'], 'sublevel2':""}}}

    and returns a list of items in the format of:
        (directory, top/level1)
        (file, top/level1/item1)
        (file, top/level1/item2)
        (directory, top/level2/sublevel1)
        (file, top/level2/sublevel1/item1)
        (file, top/level2/sublevel1/item1)
        (directory, top/level2/sublevel2)

    node - top level node
    parents - technically the upper directory.  Meant to be a tuple.
    """
    _logger = logging.getLogger('standard.core')

    _logger.debug("node - {0}".format(node))
    if isinstance(node, dict):

        keys = node.keys()

        if parents is None:
            parents = tuple()

        _logger.debug("keys - {0}".format(keys))

        nodelist = list()
        for k in keys:
            _logger.debug("----beg for loop for k in keys----")
            _logger.debug("k - {0}".format(k))
            parentslist = list(parents)
            parentslist.append(k)
            parentstuple = tuple(parentslist)
            _logger.debug("parentslist - {0}".format(parentslist))

            keylist = tree(node[k], parentstuple)

            _logger.debug("keylist - {0}".format(keylist))
            _logger.debug("parents - {0}".format(parents))

            if node[k] is None or not isinstance(node[k], dict):

                _logger.debug(
                    "if node[k] == NONE or not isinstance(node[k], dict)"
                    "\n\tnode - {0}\n\tk - {1}\n\tparents - {2}".format(
                        node, k, parents))

                _logger.debug("len(parents) - ".format(len(parents)))
                path = "/".join(parents)

                if len(parents) == 0:
                    _logger.debug("True!")
                    path = ""
                if len(parents) == 0:
                    keylist.insert(0, ("directory", "{0}".format(k)))
                else:
                    keylist.insert(0, ("directory", "{0}/{1}".format(path, k)))

            nodelist.extend(keylist)
            _logger.debug("----end for loop for k in keys----")
        return nodelist


#def findarg(argkey):
#    """Searches command line input for a key
#    occurence and the value associated with that key
#
#    Keyword argumetns:
#        argkey -- the key flag we are looking for
#        """
#    if sys.argv.count(argkey) > 0:
#        index_key = sys.argv.index(argkey)
#        if index_key + 2 <= len(sys.argv):
#            return sys.argv[index_key + 1]
#
#    elif isinstance(node, list):
#        listval = list()
#        for l in node:
#            path = "/".join(parents)
#
#            listval.append(("file","{0}/{1}".format(path, l)))
#        return listval
#
#    # when the configuration file has a line like
#    # scripts:
#    #   tools:
#    # and nothing afterwards (it's an empty directory), then the recursive
#    # function will go into scripts['tools'] to get a "None" value.  So if
#    # you see that "node" is equal to "None" it means you need to return an
#    # empty list() (DO NOT return a list with the current directory structure)
#    # because we automatically do that when we hit file.  In the case of file,
#    # we also create a list, only we fill it and return that.  Same thing
#    # here only we're not bothering to fill the list (the program thinks there
#    # should be a file there in that case, and it automatically adds in the
#    # directory for that file.  oh just figure it out, OK?
#    elif node == None:
#        return list()


def findarg(argkey, argv):
    """Searches command line input for a key
    occurence and the value associated with that key

    Keyword argumetns:
        argkey -- the key flag we are looking for
        argv -- the list with command line inputs
        """
    if argv.count(argkey) > 0:
        index_key = argv.index(argkey)
        if index_key + 2 <= len(argv):
            return argv[index_key + 1]


def findargs(key1, key2, args):
    """ Same as findarg above, only this one searches for two possible keys
    Keyword argumetns:
        key1 -- first possible key arg we are looking for
        key2 -- second possible key arg we are looking for
        argv -- the list with command line inputs
    """
    val = findarg(key1, args)
    if not val:
        val = findarg(key2, args)

    return val


def findflag(flag, argv):
    """Check command line arguments for a flag argument

    Keyword argumetns:
        flag -- the str representing the flag, e.g. '-f'
        argv -- the list with command line inputs
        """
    if argv.count(flag) > 0:
        return True

    return False


def findflags(flag1, flag2, args):
    """ Same as findflag above, only this one searches for two possible
    flag keys

    Keyword argumetns:
        flag1 -- first possible key arg we are looking for
        flag2 -- second possible key arg we are looking for
        argv -- the list with command line inputs
    """
    val = findflag(flag1, args)
    if not val:
        val = findflag(flag2, args)

    return val


def lastindex(lst, item):
    """
    This helper function solves the problem of finding the last occurence of
    the specified item in a list

    taken from:
        http://stackoverflow.com/questions/6890170/ \
            python-how-to-find-last-occurrence-in-a-list-in-python

    Keywrod arguments:
        lst -- the list being searched
        item -- the item we are looking for
    """
    from itertools import dropwhile

    try:
        return dropwhile(lambda x: lst[x] != item,
                         reversed(xrange(len(lst)))).next()
    except StopIteration:
        raise ValueError("rindex(lst, item): item not in list")



import os
import sys
import re
import logging
import elpotrero.lib.files as libfiles
import elpotrero.lib.util as elutil
import configurationvalues as confvals


_logger = None


def getconfigurationpath(filelayoutkey, filename):
    """ Util to get the full path of conf file"""

    pathfile = os.path.join(
        confvals.getprojectpath(),
        confvals.getlayoutvalue(filelayoutkey),
        '_build',
        filename)

    _checkpathexists(pathfile)

    return pathfile


def _getpath(pathkey):
    """ Another simple util to cut down on all the code.

    All it does is pull out the configvalue based on the path key and does
    some error checking to make sure the path exists.
    """
    global _logger

    pathfile = confvals.getconfigvalue(pathkey)

    _logger.debug("key = {0}, path = {1}".format(pathkey, pathfile))

    _checkpathexists(pathfile)

    return pathfile


def _checkpathexists(pathfile):
    """ This util is just a helper that checks if the path/file exists.  If
    it does not, then exit and give a message
    """
    global _logger

    ipsrcfile = os.path.exists(pathfile)

    _logger.debug("{0} exist - {1}".format(pathfile, ipsrcfile))

    if not ipsrcfile:
        _logger.info("exiting because {0} does not exist".format(pathfile))
        sys.exit(1)


def getdestinations():
    # these are all the paths to the files we intend to modify
    # all the configuration options are located in basic_configuration.conf
    pdst = dict()
    pdst['bindnamed'] = _getpath('paths.bind.named')
    pdst['bindzones'] = _getpath('paths.bind.zones')
    pdst['nginxavail'] = _getpath('paths.nginx.available')
    pdst['nginxenabl'] = _getpath('paths.nginx.enabled')
    pdst['supervisor'] = _getpath('paths.supervisor\.conf')

    project = confvals.getconfigvalue('project')
    projectpath = confvals.getprojectpath()
    pdst['django'] = "{0}/{1}".format(projectpath, project)

    return pdst


def getsources():
    """ path to the conf versions we have that are meant to be installed
     these files are all installed in scripts/conf/ name of conf / _build
     we're going to use this file name a few times
     """

    global _logger

    confname = getconfnames()

    psrc = dict()
    psrc['bindnamed'] = getconfigurationpath('build.paths.bind',
                                             'named.conf.local')

    psrc['bindzones'] = getconfigurationpath('build.paths.bind',
                                             confname['bind'])

    psrc['nginxavail'] = getconfigurationpath('build.paths.nginx',
                                              confname['nginx'])

    psrc['supervisor'] = getconfigurationpath('build.paths.supervisor',
                                              confname['supervisor'])

    _logger.debug("psrc['bindnamed'] = {0}".format(psrc['bindnamed']))
    _logger.debug("psrc['bindzones'] = {0}".format(psrc['bindzones']))
    _logger.debug("psrc['nginxavail'] = {0}".format(psrc['nginxavail']))
    _logger.debug("psrc['supervisor'] = {0}".format(psrc['supervisor']))

    return psrc


def getconfnames():
    """
    returns a dictionary of the correct names of the configuration files
    we are using this does NOT return full path names!
    """
    project = confvals.getconfigvalue('project')
    domain = confvals.getconfigvalue('domain')

    confnames = dict()
    confnames['bind'] = 'db.{0}.{1}'.format(project, domain)
    confnames['nginx'] = '{0}.{1}'.format(project, domain)
    confnames['supervisor'] = '{0}.conf'.format(project)

    return confnames


def installconfigurationfiles(dests, source):
    """
    Contains all the code to install the configuration files found in
    scripts/conf to /etc/bind, /etc/nginx, etc.

    Keyword Argumetns

    dests - destination paths to where we intend to copy and modify
                configuration files

    source - source paths to the configuration files we have in the
                scripts/conf directory
    """
    # bind installation
    # bindnamed is contents of the file found in /etc/bind/named.conf
    # bindconf is the addition we wish to make to /etc/bind/named.conf
    fbind = open(dests['bindnamed'], 'r')
    bindnamed = fbind.read()
    fbind.close()

    fbind = open(source['bindnamed'], 'r')
    bindconf = fbind.read()
    fbind.close()

    # if the addition is not already there, then add it and write it
    m = re.search(bindconf, bindnamed)
    if m is None:
        fbind = open(dests['bindnamed'], 'w')
        fbind.write("{0}\n{1}".format(bindnamed, bindconf))

    # now copy the zone file we have for this project
    # to the /etc/bind/zones directory
    libfiles.copyanything(source['bindzones'],
                          dests['bindzones'])

    # nginx installation
    #   first place our nginx conf file into /etc/nginx/sites-available
    #   then symlink it to nginx/sites-enabled
    libfiles.copyanything(source['nginxavail'],
                          dests['nginxavail'])

    confname = getconfnames()
    src = os.path.join(dests['nginxavail'], confname['nginx'])
    dst = os.path.join(dests['nginxenabl'], confname['nginx'])

    libfiles.symcheck(src, dst)

    # supervisor installation
    libfiles.copyanything(source['supervisor'],
                          dests['supervisor'])


def uninstallconfigurationfiles(targetpaths, sources):
    """
    Contains all the code to delete installed configuration files found in
    /etc/bind, /etc/nginx, etc.

    Keyword Argumetns

    dests - destination paths to where we installed the configuration files
        that are meant to be deleted

    source - source paths to the configuration files we have in the
                scripts/conf directory

    """
    # bind un-installation

    # we have to check /etc/bind/named.conf.local for anything we put
    # in there and delete it
    fbind = open(targetpaths['bindnamed'], 'r')
    bindtarget = fbind.read()
    fbind.close()

    fbind = open(sources['bindnamed'], 'r')
    bindconf = fbind.read()
    fbind.close()

    # if the addition to named.conf.local there, then
    #   delete it and rewrite the file
    m = re.search(bindconf, bindtarget)
    if m:
        bindtarget = re.sub(bindconf, "", bindtarget)
        fbind = open(targetpaths['bindnamed'], 'w')
        fbind.write(bindtarget)

    confname = getconfnames()

    # remove the zone file from /etc/bind/zones
    dst = os.path.join(targetpaths['bindzones'], confname['bind'])
    if os.path.exists(dst):
        os.remove(dst)

    # nginx uninstall

    # remove the file from /etc/nginx/sites-available
    available = os.path.join(targetpaths['nginxavail'], confname['nginx'])
    if os.path.exists(available):
        os.remove(available)

    # remove the symlink from /etc/nginx/sites-enabled
    enabled = os.path.join(targetpaths['nginxenabl'], confname['nginx'])
    if os.path.exists(enabled):
        os.remove(enabled)

    # remove conf file from /etc/supervisor/conf.d
    supervisor = os.path.join(targetpaths['supervisor'],
                              confname['supervisor'])

    if os.path.exists(supervisor):
        os.remove(supervisor)


def help():
    return """
This script is used to install configuration files from scripts/conf directory
to various locations in /etc.
Such as /etc/bind/zones /etc/nginx/sites-available, ...

There are two basic modes, install and uninstall

Note that the script will exit during an install if it sees that the required
directories for installation do not exist.  However, it doesn't do a check on
the script/conf files

Usage: sudo $VIRTUAL_ENV/bin/python confinstall.py [FLAG]

flags:
    -h, --help          this help file

    -d, --debug         turn debug logging information on

    -i, --install       run the installation script

    -u, --uninstall     run the uninstallation script

    -is, --installsettings  install settings files as settings.modd
    """


def main(args):
    global _logger
    formatter = elutil.create_logformatter("%(filename)s %(message)s", "")
    elutil.setup_logging('/tmp/logs', scrnlog=True,
                         logname='scripts.bootstrap.installconfs.debug',
                         screen_formatter=formatter,
                         debug=elutil.findflags('-d', '--debug', args))

    _logger = logging.getLogger('standard.core')

    destinationpaths = getdestinations()
    sourcepaths = getsources()

    if elutil.findflags('-h', '--help', args):
        print help()
        sys.exit(0)

    if elutil.findflags('-i', '--install', args):
        installconfigurationfiles(destinationpaths, sourcepaths)
        sys.exit(0)

    if elutil.findflags('-u', '--uninstall', args):
        uninstallconfigurationfiles(destinationpaths, sourcepaths)
        sys.exit(0)

if __name__ == "__main__":
    sys.exit(main(sys.argv[1:]))



"""
Django settings for {{project}} project.

For more information on this file, see
https://docs.djangoproject.com/en/1.6/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.6/ref/settings/
"""

import os
import sys

from settings_local import *
from settings_media import *

sys.path.insert(0, os.path.join(BASE_DIR, 'apps'))

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.6/howto/deployment/checklist/

# Application definition

INSTALLED_APPS = (
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',

    'django.contrib.webdesign',
    'django_countries',

    'debug_toolbar',
    'south',
    'mediagenerator',
    'gunicorn',

    # this is app needs to be installed by me
    'utils',
)


# After the MIDDLEWARE_CLASSES and TEMPLATE_DIRS variables are declared
# I extend them with variables I created in settings_local
#
# This is not very elegant, but the reason I do it this way, is because
# if I just try to add on to MIDDLEWARE_CLASSES, or TEMPALTE_DIRS, then
# this file doesn't know about it yet see settings_local gets called before
# settings.py has finished loading, so that variable hasn't been initialized
# properly yet  instead I created this variable, which does get fully loaded,
# so I can call it from settings.py

MIDDLEWARE_CLASSES = [
    # Media middleware has to come first
    'mediagenerator.middleware.MediaMiddleware',

    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

MIDDLEWARE_CLASSES.extend(MIDDLEWARE_CLASSES_ADDON)

TEMPLATE_DIRS = [
    # Put strings here, like "/home/html/django_templates"
    #    or "C:/www/django/templates".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
    os.path.join(BASE_DIR, 'templates'),
]

TEMPLATE_DIRS.extend(TEMPLATE_DIRS_ADDON)


TEMPLATE_CONTEXT_PROCESSORS = (
    "django.contrib.auth.context_processors.auth",
    "django.core.context_processors.debug",
    "django.core.context_processors.i18n",
    "django.core.context_processors.media",
    "django.core.context_processors.static",
    "django.core.context_processors.tz",
    "django.contrib.messages.context_processors.messages",
    "django.core.context_processors.request",
)

# there is no need to put this in settings_local, since "project" is used
# across different branches.
ROOT_URLCONF = '{{project}}.urls'
WSGI_APPLICATION = '{{project}}.wsgi.application'

# https://docs.djangoproject.com/en/1.6/ref/settings/#databases
# this is located in settings_local

# Internationalization
# https://docs.djangoproject.com/en/1.6/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.6/howto/static-files/
# this is located in settings_local
# django-shop variables



# local settings for {{project}} project.

import os

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
# this is used in the main settings file as well as here
# (GLOBAL_MEDIA_DIRS uses this)
BASE_DIR = os.path.dirname(os.path.dirname(__file__))

# used for debug_toolbar
INTERNAL_IPS = ('{{address}}',)

PROJECT_STATE = '{{branch}}'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = True
TEMPLATE_DEBUG = DEBUG

# DEBUG_TOOLBAR_PATCH_SETTINGS = False

ADMINS = (
    ('{{admin_name}}', '{{admin_email}}'),
)

MANAGERS = ADMINS

DATABASES = {
    'default': {
        # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
        'ENGINE': 'django.db.backends.{{db_engine}}',
        'NAME': '{{project}}_{{branch}}_db',
        'USER': '{{user}}',          # Not used with sqlite3.
        'PASSWORD': '{{db_password}}',     # Not used with sqlite3.
        'HOST': '',
        'PORT': '',
    }
}

SITE_ID = 1

# change this to the sitename when you are using forward
# Only MEDIA_URL and STATIC_URL are using the sitename variable for when
# I have to switch to the forward in development
#
# MEDIA_ROOT and STATIC_ROOT do not need it under any circumstances
#
SITENAME = "{{project}}.{{domain}}"
# SITENAME = "shopdev-ronny.fwd.wf"

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/home/media/media.lawrence.com/media/"
MEDIA_ROOT = '{{rootpath}}/{{project}}.{{domain}}/public/media/dynamic/'

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash.
# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
MEDIA_URL = 'http://{0}/media/'.format(SITENAME)

# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/home/media/media.lawrence.com/static/"
STATIC_ROOT = '{{rootpath}}/{{project}}.{{domain}}/public/media/static/'

# URL prefix for static files.
# Example: "http://media.lawrence.com/static/" or STATIC_URL = '/static/'
STATIC_URL = 'http://{0}/static/'.format(SITENAME)

# Additional locations of static files
STATICFILES_DIRS = (
    # Put strings here, like "/home/html/static" or "C:/www/django/static".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
)


# this is not very elegant, but the reason I do it this way, is because
# if I just try to add on to MIDDLEWARE_CLASSES, this file doesn't know
# about it yet see settings_local gets called before settings.py has
# finished loading, so that variable hasn't been initialized properly yet
# instead I created this variable, which does get fully loaded,
# so I can call it from settings.py

MIDDLEWARE_CLASSES_ADDON = [
    'debug_toolbar.middleware.DebugToolbarMiddleware'
]

# Make this unique, and don't share it with anybody.
# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = '{{secretkey}}'

ALLOWED_HOSTS = []

TEMPLATE_DIRS_ADDON = [
    # Put strings here, like "/home/html/django_templates"
    #    or "C:/www/django/templates".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
    "{{rootpath}}/{{project}}.{{domain}}/private/templates"
]

# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error when DEBUG=False.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse'
        }
    },
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'filters': ['require_debug_false'],
            'class': 'django.utils.log.AdminEmailHandler',
            'include_html': True,
        },
        'stream_to_console': {
            'level': 'DEBUG',
            'class': 'logging.StreamHandler'
        },
        'file': {
            'level': 'DEBUG',
            'class': 'logging.FileHandler',
            'filename': '{{rootpath}}/{{project}}.{{domain}}/logs/'
                        '{{project}}.django.debug.log',
        },
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins', 'stream_to_console'],
            'level': 'ERROR',
            'propagate': True,
        },
        'custom.debug': {
            'handlers': ['file'],
            'level': 'DEBUG',
            'propagate': True,
        },
    }
}



import os

from settings_local import BASE_DIR
from settings_local import STATIC_URL
from settings_local import STATIC_ROOT
from settings_local import DEBUG


CRISPY_TEMPLATE_PACK = "uni_form"

MEDIA_BUNDLES = (
    ('projectname.css',
        'css/uni-form/uni-form.css',
        'css/uni-form/default.uni-form.css',
        'css/fonts/chancery.css',
     ),

    ('project.js',
        'js/jquery-1.9.1.js',
        'js/jquery-ui.js',
        'js/jquery.cookie.js',
     ),

)

# Django-MediaGenerator settings

MEDIA_DEV_MODE = DEBUG
DEV_MEDIA_URL = '/devmedia/'
PRODUCTION_MEDIA_URL = '/static/'
GLOBAL_MEDIA_DIRS = (
    os.path.join(BASE_DIR, 'media'),
    os.path.join(BASE_DIR, 'imported-sass-frameworks'),
)

# tinymce settings

TINY_JS_URL = os.path.join(STATIC_URL, 'tiny_mce/tiny_mce.js')
TINY_JS_ROOT = os.path.join(STATIC_ROOT, 'tiny_mce/tiny_mce.js')
TINYMCE_DEFAULT_CONFIG = {
    'theme': "advanced",
    'relative_urls': False,
    'cleanup_on_startup': True,
    'custom_undo_redo_levels': 10,
}



import os
import sys
import yaml
import shyaml
import elpotrero.lib.util as elutil

# Note: configuration file for this tool and all other tools in this directory
_TOOLSCONFIG = "tools.config.yaml"


def _here():
    """standard "here" helper function"""
    return os.path.dirname(os.path.realpath(__file__))


def loadyaml(configfile):
    """Helper function to pull up the config file

    returns a yaml dict
    """
    with file(configfile, 'r') as stream:
        return yaml.load(stream)


def _cwdprojectpath():
    # get the project path by splitting off the current working directory at
    # "scripts".  filelayout.yaml never changes it's path, also
    # this tool is always found next to extractconfig.py, so those
    # things can be assumed

    pathlist = os.getcwd().split(os.path.sep)
    index = elutil.lastindex(pathlist, 'scripts')
    return os.path.sep.join(pathlist[:index])


def getformalprojectpath():
    """
    Utility function to create a project path name based on the
    values found in configuration.basic
    """
    projectname = getconfigvalue('project')
    projectdir = getconfigvalue('projdir')
    branchname = getbranch()

    return "{0}/{1}/{2}".format(projectdir, projectname, branchname)


def getprojectpath():
    """
    Utility to get the project path based on WHERE THIS FILE IS LOCATED
    I'm finding the above formal project path method does not do what I want
    because it limits me to using only the  configuration file.

    I'd rather use the location of the installation files as a determiner
    of what the projdir is!
    """
    pathlist = _here().split(os.path.sep)
    index = elutil.lastindex(pathlist, 'scripts')
    return os.path.sep.join(pathlist[:index])


def getrootpath():
    """ Utility function to create a project path name based on the
    values found in configuration.basic
    """
    projectdirname = "{0}.{1}".format(
        getconfigvalue('project'), getconfigvalue('domain'))

    fullrootpath = os.path.join(
        getconfigvalue('rootpath'), projectdirname)

    return fullrootpath


def getenvironmentpath():
    """ Utility function returning the full path of the environment directory
    """
    return os.path.join(getconfigvalue('environment'), "{0}.{1}".format(
        getconfigvalue('project'), getbranch()))


def _cwdfilelayout():
    global _TOOLSCONFIG

    # Note: I have to use the _here method, because if I access this script
    # from another directory, the vm won't know where the TOOLSCONFIG file is
    ptoolsconfig = "{0}/{1}".format(_here(), _TOOLSCONFIG)
    filelayoutpath = loadyaml(ptoolsconfig)['filelayout']

    return os.path.join(_cwdprojectpath(), filelayoutpath)


def _cwdfullpath(confkey):
    """ Helper function to retrieve the configuration paths
        that are defined in the filelayout conf file

        confkey refers to either configuration.branch or configuration.basic
        which should be passed in as "configuration\.branch" or
        "configuration\.basic"

        NOTE: The values retrieved using this function are appended to the
        project directory path.  So you might want to be careful with this,
        since you could ask for a totally unrelated value and get something
        that shouldn't be appended to a project path.
    """
    ydict = loadyaml(_cwdfilelayout())
    configpath = shyaml.mget(ydict, confkey)
    return os.path.join(_cwdprojectpath(), configpath)


def _cwdconfigbasic():
    return _cwdfullpath('configuration\.basic')


def getbranch():
    """ Helper function to retrieve the name of the branch we are working on

        NOTE: There isn't any point in retrieving the config branch file, since
            all I want is the branch value
    """
    # return the branch value found in the yaml conf file configuration.branch
    bpath = _cwdfullpath('configuration\.branch')
    return loadyaml(bpath)['branch']


def getbranchindex():
    """Return the index of the branch key
        """

    branch = getbranch()
    branchlist = getconfigvalue('branch', isbranchdependent=False)

    # make sure the branch value we got is among the available branch values
    # found in configuration.basic.  If so, then return the index
    if branchlist.count(branch) == 0:

        errmsg = "branch = {0}\nbranchlist = {1}".format(branch, branchlist)

        raise ValueError("The branch value from configuration.branch doesn't"
                         " appear in configuration.basic\n."
                         + errmsg)

    return branchlist.index(branch)


def getlayoutvalue(key):
    """ Helper function to get values from the filelayout file
    """
    ydict = loadyaml(_cwdfilelayout())
    return shyaml.mget(ydict, key)


def getconfigvalue(key, isbranchdependent=True):
    """ Helper function to get values from the configuration.basic file
        a lot of the values that I'll request will depend on what branch I
        am using.

        I internally find the relevent branch using the getbranch method
        in this class

    Keyword arguments:
        key -- the key argument used

        NOTE: shyaml.mget drills down to find the key value, for example:
            "tools.config" is assumed to be a value in dictionary form

            tools = { 'config':someval }

            but "tools\.config" would be considered a single keyname of:

            tools.config = someval
    """
    ydict = loadyaml(_cwdconfigbasic())
    value = shyaml.mget(ydict, key)

    # if I don't care about the branch, then just
    # return whatever value I find.
    if not isbranchdependent:
        return value

    errmsg_vals = "\nValues are:\nbranch = {0}\nconfigurationpath = {1}\n" \
        "key requested = {2}\nextracted ymldict = {3}\n".format(
            getbranch(), _cwdconfigbasic(),
            key, ydict)

    if type(value) is list:
        bindex = getbranchindex()

        # check to make sure that the len of the value list isn't less than the
        # branch index we are searching for.
        if len(value) < bindex:
            raise ValueError("The branch index is higher than the length of "
                             "the list value returned by the key you "
                             "requested.\nThis is probably a problem with the "
                             "configuration.basic file.\n"
                             "You should check the key in it.\n" + errmsg_vals)
        # Otherwise, continue to return the value based on the bindex
        return value.pop(bindex)
    else:
        return value


def getconfigkeys():
    """ Helper function to return the keys for the configuration.basic file
    """
    ydict = loadyaml(_cwdconfigbasic())
    return ydict.keys()


def getfilelayoutkeys():
    """ Helper function to return the keys for the filelayout file
    """
    ydict = loadyaml(_cwdfilelayout())
    return ydict.keys()


def getconfigurationcontext():
    """ The purpose of this function is to create a context dictionary
    for use in a template renderer

    if you look at how keys are generated, you'll notice I replace the
    '.' with a '\.'

    e.g.  bind.zones ->  bind\.zones
    """
    context = dict()
    keys = getconfigkeys()

    for k in keys:
        context[k] = getconfigvalue(k)

    return context


def main(args):
    print getconfigurationcontext()


if __name__ == "__main__":
    sys.exit(main(sys.argv[1:]))



import os
import sys
import logging
import elpotrero.lib.files as libfiles
import elpotrero.lib.util as elutil
from loadconfigtools import setup_python_path


def _here():
    """standard "here" helper function"""
    return os.path.dirname(os.path.realpath(__file__))


def main(args):
    """ This is the createdirstruct or Create Directory Structure script

    The purpose of this script is to create the rootpath directory
    the rootpath directory is where the project is found by web services

    There are two things involved in creating the rootpath
    1. Creating the actual folders in rootpath to store and link to
    2. Creating symlinks between files in the project home and rootpath

    Keep in mind that project home is where we keep the installation,
    it's set up in a way that allows me to easily keep track of the files
    """

    global _logger
    formatter = elutil.create_logformatter("%(filename)s %(message)s", "")
    elutil.setup_logging('/tmp/logs', scrnlog=True,
                         logname='scripts.bootstrap.createdirstruct.debug',
                         screen_formatter=formatter,
                         debug=elutil.findflag('--d', args))

    _logger = logging.getLogger('standard.core')

    # add the directory where configurationvalues is found to the sys.path
    setup_python_path()

    import configurationvalues as confvals

    _logger.info("importing configuration values")

    projectpath = confvals.getprojectpath()
    fullrootpath = confvals.getrootpath()
    envrpath = confvals.getenvironmentpath()

    fpath_gunicorn = confvals.getlayoutvalue('gunicornscript')

    _logger.debug("set fullrootpath = {0}".format(fullrootpath))
    _logger.debug("set envrpath = {0}".format(envrpath))
    _logger.debug("set fpathgunicorn = {0}\n".format(fpath_gunicorn))

    _logger.info("making directories in {0}".format(fullrootpath))

    libfiles.mkdir_p(os.path.join(fullrootpath, 'private'))
    libfiles.mkdir_p(os.path.join(fullrootpath, 'backup'))
    libfiles.mkdir_p(os.path.join(fullrootpath, 'logs', 'nginx'))
    libfiles.mkdir_p(os.path.join(fullrootpath, 'logs', 'gunicorn'))
    libfiles.mkdir_p(os.path.join(fullrootpath, 'logs', 'supervisor'))
    libfiles.mkdir_p(os.path.join(fullrootpath, 'scripts'))
    libfiles.mkdir_p(os.path.join(fullrootpath, 'public', 'media', 'dynamic'))
    libfiles.mkdir_p(os.path.join(fullrootpath, 'public', 'media', 'static'))

    libfiles.mkdir_p(envrpath)

    libfiles.symcheck(os.path.join(projectpath, 'templates'),
                      os.path.join(fullrootpath, 'private', 'templates'))

    # due to changes in gunicorn the following line was changed from
    # projectpath/project to projectpath.  Gunicorn is looking for
    # projectpath/project.wsgi to execute gunicorn project.wsgi:application
    libfiles.symcheck(projectpath,
                      os.path.join(fullrootpath, 'private', 'djangoproject'))

    libfiles.symcheck(os.path.join(projectpath, fpath_gunicorn),
                      os.path.join(fullrootpath, 'scripts', 'gunicorn.sh'))

    libfiles.symcheck(envrpath,
                      os.path.join(fullrootpath,
                                   'private', 'virtual_environment'))

if __name__ == "__main__":
    sys.exit(main(sys.argv[1:]))



import inspect, os, errno, shutil, yaml, re
import elpotrero.lib.util as libutil

def symcheck(src, dst):
    """checks to see if the sym link exists, if not, creates the link"""
    if not os.path.lexists(dst):
        os.symlink(src, dst)
    
def mkdir_p(path):
    """duplicates functionality of bash "make -p" command"""
    try:
        os.makedirs(path)
    except OSError as exc:
        if exc.errno == errno.EEXIST:
            pass
        else: raise


def hereis():
    print os.getcwd()


def load_yaml(src):
    stream = open(src, 'r')
    extract = yaml.load(stream)
    stream.close()
    return extract 

def copyanything(src, dst):
    """
        copies everything in a directory tree, or copies a file 
            see http://stackoverflow.com/questions/1994488/copy-file-or-directory-in-python
    """
    try:
        shutil.copytree(src, dst)
    except OSError as exc: # python >2.5
        if exc.errno == errno.ENOTDIR:
            shutil.copy(src, dst)
        else: raise


def removedirectory(directoryname):
    directorypath = os.path.join(os.getcwd(), directoryname)
    return removedirectory_abs(directorypath, directoryname)


def removedirectory_abs(directorypath, directoryname=""):

    if os.path.exists(directorypath):
        # check if it is a directory
        if os.path.isdir(directorypath):
            isremove = libutil.confirmation("Found a {0} directory already in place. Remove it [Y/n]?".format(directoryname))
            if isremove:
                shutil.rmtree(directorypath)
            else:
                libutil.exit_err("Cannot install over existing directory.")

        elif os.path.isfile(directorypath):
            isremove = libutil.confirmation("while trying to remove previous instance of {0}, came across a file that has that name in the current working directory.  Would you like to remove it anyway [Y/n]? ".format(directoryname))
            if isremove:
                os.unlink(directorypath)
            else:
                libutil.exit_err("Cannot install over existing file (where the {0} directory is supposed to go).".format(directoryname))

        else:
            libutil.exit_err("Exiting with error - trying to remove previous instance of {0} directory, and found something that is not registering as either a file or a directory.".format(directoryname))
    


def expand_pathlist(directorylist, expansionterms, expandkey):
    """creates the script directories

        directorylist - a list of directory paths
        expansionterms - a list of expansion terms
        expandkey - the keyword to check for in the directorylist items

        return an expanded list based on the terms given in expansionterms
    
    """
    expansionlist = list()
    
    for pathstr in directorylist: 
        # check to see if the expandkey is located within the path string
        # if it is than break the pathstring apart and find the full word
        # used inside the string and then search for that word among the listed
        # items of the path.
        if pathstr.find(expandkey) != -1:
            plist = pathstr.split('/')
            plistkey = libutil.regxListFind(plist, expandkey)
            plist_index = plist.index(plistkey)
            prog = re.compile(expandkey)

            for expandterm in expansionterms:
                sub = prog.sub(expandterm, plistkey) 
                plist[plist_index] = sub 

                # make sure to rejoin the pathlist with a "/"
                expansionlist.append("/".join(plist))
        else:
            # no need to rejoin anything since we never broke it down
            expansionlist.append(pathstr)

    return expansionlist




import os
import sys
import logging
import elpotrero.lib.util as libutil
import elpotrero.lib.files as libfiles
from loadconfigtools import setup_python_path


def main(args):
    """
    Note: The purpose of this script is to create a django project directory
    in the projects main installation directory. e.g:

    home/user/project/... -- this is where the django proj dir goes--


    using django-admin we also customize our own modified version of the
    settings.py file, but we keep both the one that is normally created
    by django-admin, and the custom version in two files

    settings.modd.py - the custom version
    settings.orig.py - the original version django-admin makes
    """
    setup_python_path()
    import configurationvalues as confvals

    global _logger
    formatter = libutil.create_logformatter("%(filename)s %(message)s", "")
    libutil.setup_logging('/tmp/logs', scrnlog=True,
                          logname='scripts.bootstrap.startproject.debug',
                          screen_formatter=formatter,
                          debug=libutil.findflag('--debug', sys.argv))

    _logger = logging.getLogger('standard.core')

    projectname = confvals.getconfigvalue('project')
    projectpath = confvals.getprojectpath()
    projectbranch = confvals.getbranch()

    if not os.path.exists(projectpath):
        print "target directory needs to be created first"
        print "target directory is = {0}".format(projectpath)
        sys.exit(1)

    # Note: this is usually located in scripts/conf/django/_build
    # Check filelayout.conf to find the path to where we install the custom
    # generated settings.py
    pdjango = confvals.getlayoutvalue('build.paths.django')
    src_settings = os.path.join(projectpath, pdjango, '_build')
    _logger.debug("pdjango = {0}".format(pdjango))
    _logger.debug("projectpath = {0}".format(projectpath))
    _logger.debug("src_settings = {0}".format(src_settings))

    dtmp = os.path.join(os.getcwd(), 'tmp')
    if not os.path.exists(dtmp):
        os.makedirs(dtmp)
    os.chdir(dtmp)

    commanddict = dict()
    commanddict['admin'] = ['django-admin.py', 'startproject',  projectname]
    libutil.execcommand(commanddict, 'admin', 'django-admin')

    # sourcedir is where the files created by django-admin are located
    sourcedir = os.path.join(dtmp, projectname)

    # Check if manage.py is in /projectpath/manage.py
    #
    # Note: manage.py has to be one directory above
    #   /home/projectpath/project/settings.py
    #
    if not os.path.exists(os.path.join(projectpath, 'manage.py')):
        libfiles.copyanything(os.path.join(sourcedir, 'manage.py'),
                              os.path.join(projectpath, 'manage.py'))

    if not os.path.exists(os.path.join(projectpath, projectname)):
        libfiles.copyanything(os.path.join(sourcedir, projectname),
                              os.path.join(projectpath, projectname))

        dst_settings = os.path.join(projectpath, projectname, '_settings')
        if not os.path.exists(dst_settings):
            os.makedirs(dst_settings)

        # copy over the settings.py file made by django-admin to settings.orig
        libfiles.copyanything(
            os.path.join(sourcedir, projectname, 'settings.py'),
            os.path.join(dst_settings, 'settings.py.orig'))

        # get rid of the old settings.py
        # Note: this is not located in projectpath/project/_settings
        # it's located in projectpath/project
        os.remove(os.path.join(projectpath, projectname, 'settings.py'))

        # copy over our version of settings.py and link it to settings.modd
        libfiles.copyanything(
            os.path.join(src_settings, 'settings.py'),
            os.path.join(dst_settings, 'settings.py.modd'))

        libfiles.copyanything(
            os.path.join(src_settings, 'settings_main.py'),
            os.path.join(dst_settings, 'settings_main.py'))

        localsettings = "local_{0}.py".format(projectbranch)
        libfiles.copyanything(
            os.path.join(src_settings, 'settings_local.py'),
            os.path.join(dst_settings, localsettings))

        # now make a symlink between settings.modd and settings.py
        #  so that now the custom settings file is what will be used
        # we are linking projectpath/project/_settings/settings.py.modd
        # to projectpath/project/settings.py
        libfiles.symcheck(
            os.path.join(dst_settings, 'settings.py.modd'),
            os.path.join(projectpath, projectname, 'settings.py'))

        libfiles.symcheck(
            os.path.join(dst_settings, localsettings),
            os.path.join(projectpath, projectname, 'settings_local.py'))

        # Note: we keep a copy of the original and the mod so I can compare
        # and contrast between the two

    libfiles.removedirectory(dtmp)

if __name__ == "__main__":
    sys.exit(main(sys.argv[1:]))




import subprocess
import sys
import time
import elpotrero.lib.util as elutil

# NOTE: MAKE SURE TO SET THE PYTHONPATH on root to include the elpotrero
# library, if you only set it in the default user library, then call sudo,
# python will NOT pick it up.
#
# HOWTO:
#
# http://stackoverflow.com/questions/7969540/
#    pythonpath-not-working-for-sudo-on-gnu-linux-works-for-root
#
# 1. put the elpotrero library in /usr/local/lib/py
# 2. add PYTHONPATH=$PYTHONPATH:/usr/local/lib/py to /etc/bash.bashrc
# 3. add PYTHONPATH to Default env_keep += "PYTHONPATH" in /etc/sudoers
# 4. remove Defaults !env_reset from sudoers if present


def execute(cmd_dict, cmd, name):
    info = elutil.execcommand(cmd_dict, cmd, name)
    print info['message']
    if info['retval'] != 0:
        sys.exit(info['retval'])


def main():
    nginx_cmd = "/etc/init.d/nginx"
    supervisor_cmd = "/etc/init.d/supervisor"

    nginx = dict()
    supervisor = dict()

    nginx['start'] = [nginx_cmd, "start"]
    nginx['stop'] = [nginx_cmd, "stop"]
    nginx['status'] = [nginx_cmd, "status"]

    supervisor['start'] = [supervisor_cmd, "start"]
    supervisor['stop'] = [supervisor_cmd, "stop"]
    supervisor['status'] = [supervisor_cmd, "status"]

    # before executing make sure the actual processes are running
    if subprocess.call(nginx['status']) == 0:
        execute(nginx, "stop", "nginx")
    if subprocess.call(supervisor['status']) == 0:
        execute(supervisor, "stop", "supervisor")

    # if we got to this stage then we should have exited the subprocess
    # however, sometimes it takes a second or two to kick out, in that case
    # check to see if it is still running, and if so, wait that extra
    # second or so
    if subprocess.call(nginx['status']) == 0 or subprocess.call(supervisor['status']) == 0:

        time.sleep(2)

    execute(nginx, "start", "nginx")
    execute(supervisor, "start", "supervisor")

main()



from distutils.core import setup

setup(
    name='Elpotrero',
    version='1.6.2',
    author='Ronny Abraham',
    author_email='this.ronny@gmail.com',
    packages=['elpotrero', 'elpotrero.lib', ],
    license='Creative Commons Attribution-Noncommercial-Share Alike license',
    description='libraries for installing a basic django frame',
)



#!/usr/bin/env python
import os
import sys
import yaml
import elpotrero.lib.util as elutil


def getprojectpath():
    """ Helper function to find the project path"""

    pathlist = os.getcwd().split(os.path.sep)
    index = elutil.lastindex(pathlist, 'scripts')
    return os.path.sep.join(pathlist[:index])


# this function has to be set up before it's called
def setup_python_path():
    """ This function appends to the python path the directory where the
        configuration tool is"""

    with file("./meta.yaml", 'r') as stream:
        filelayout = yaml.load(stream)['filelayout']

    with file(os.path.join(getprojectpath(), filelayout), 'r') as stream:
        configdir = yaml.load(stream)['libpath.tools.config']

    sys.path.append(os.path.join(getprojectpath(), configdir))

setup_python_path()
import configurationvalues as confvals


def getconftool():
    value = confvals.getlayoutvalue('tools.config')
    return os.path.join(getprojectpath(), value)


def getbranchtool():
    value = confvals.getlayoutvalue('tools.branch')
    return os.path.join(getprojectpath(), value)


def getgeneratetool():
    value = confvals.getlayoutvalue('tools.generate')
    return os.path.join(getprojectpath(), value)


def main(args):
    keyarg = elutil.findarg("-k", args)

    if keyarg == "conftool":
        print getconftool()
    elif keyarg == "branchtool":
        print getbranchtool()
    elif keyarg == "generatetool":
        print getgeneratetool()


if __name__ == "__main__":
    sys.exit(main(sys.argv[1:]))
